Name:      libgeotiff
Version:   1.4.3
Release:   1
Summary:   GeoTIFF format library
Group:     System Environment/Libraries
License:   MIT
URL:       https://trac.osgeo.org/geotiff/
Source0:   http://download.osgeo.org/geotiff/%{name}/%{name}-%{version}.tar.gz
Patch0:    %{name}-%{version}-aix.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: libtiff-devel >= 4.0.10-1
BuildRequires: libjpeg-devel >= 9c-1
BuildRequires: proj-devel >= 5.2.0-1
BuildRequires: zlib-devel >= 1.2.3-7
Requires: libtiff >= 4.0.10-1
Requires: libjpeg >= 9c-1
Requires: proj >= 5.2.0-1
Requires: zlib >= 1.2.3-7

%define _libdir64 %{_prefix}/lib64

%description
GeoTIFF represents an effort by over 160 different remote sensing, 
GIS, cartographic, and surveying related companies and organizations 
to establish a TIFF based interchange format for georeferenced 
raster imagery.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Development Libraries for the GeoTIFF file format library
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: libtiff-devel >= 4.0.10-1
Requires: libjpeg-devel >= 9c-1
Requires: proj-devel >= 5.2.0-1
Requires: zlib-devel >= 1.2.3-7
Requires: pkg-config

%description devel
The GeoTIFF library provides support for development of geotiff image format.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc_r -q64" or "gcc -maix64".


%prep
%setup -q
%patch0
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
export CC="xlc_r"

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --disable-shared --enable-static \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --with-jpeg=%{_prefix} \
    --with-libtiff=%{_prefix} \
    --with-proj=%{_prefix} \
    --with-zip=%{_prefix}
make %{?_smp_mflags}

CreateExportList -X64 %{name}.exp .libs/%{name}.a
${CC} -qmkshrobj .libs/%{name}.a -o shr64.o -bE:%{name}.exp -ltiff -lproj
rm -f %{name}.exp .libs/%{name}.a

# create the shared library to stay compatible with previous versions
/usr/bin/ar -rv .libs/%{name}.a ./shr64.o

# finish the build now...
/usr/bin/rm -f bin/*.o
make %{?_smp_mflags}

# create pkgconfig file
cat > %{name}.pc <<EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir64}
includedir=%{_includedir}

Name: %{name}
Description: GeoTIFF file format library
Version: %{version}
Libs: -L\${libdir} -lgeotiff
Cflags: -I\${includedir}
EOF

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --disable-shared --enable-static \
    --prefix=%{_prefix} \
    --with-jpeg=%{_prefix} \
    --with-libtiff=%{_prefix} \
    --with-proj=%{_prefix} \
    --with-zip=%{_prefix}
make %{?_smp_mflags}

CreateExportList %{name}.exp .libs/%{name}.a
${CC} -qmkshrobj .libs/%{name}.a -o shr.o -bE:%{name}.exp -ltiff -lproj
rm -f %{name}.exp .libs/%{name}.a

# create the shared library to stay compatible with previous versions
/usr/bin/ar -rv .libs/%{name}.a ./shr.o

# finish the build now...
/usr/bin/rm -f bin/*.o
make %{?_smp_mflags}

# create pkgconfig file
cat > %{name}.pc <<EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir64}
includedir=%{_includedir}

Name: %{name}
Description: GeoTIFF file format library
Version: %{version}
Libs: -L\${libdir} -lgeotiff
Cflags: -I\${includedir}
EOF


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
gmake DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
)

cd ../32bit
export OBJECT_MODE=32
gmake DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

# create the AIX-style shared library
/usr/bin/rm -f ${RPM_BUILD_ROOT}%{_libdir}/%{name}.a
/usr/bin/ar -X32 -rv ${RPM_BUILD_ROOT}%{_libdir}/%{name}.a ./shr.o
/usr/bin/ar -X64 -q  ${RPM_BUILD_ROOT}%{_libdir}/%{name}.a ../64bit/shr64.o

# install manually some file
cp bin/makegeo ${RPM_BUILD_ROOT}%{_bindir}
cp ../64bit/bin/makegeo ${RPM_BUILD_ROOT}%{_bindir}/makegeo_64
chmod 0755 ${RPM_BUILD_ROOT}%{_bindir}/makegeo*

# install the pkgconfig file
mkdir -p ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig
mkdir -p ${RPM_BUILD_ROOT}%{_libdir64}/pkgconfig
cp %{name}.pc ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig/
cp ../64bit/%{name}.pc ${RPM_BUILD_ROOT}%{_libdir64}/pkgconfig/
chmod 0644 ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig/%{name}.pc
chmod 0644 ${RPM_BUILD_ROOT}%{_libdir64}/pkgconfig/%{name}.pc

echo  >> ${RPM_BUILD_ROOT}%{_datadir}/epsg_csv/codes.csv

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
#[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files 
%defattr(-,root,system,-)
%doc 32bit/ChangeLog 32bit/LICENSE 32bit/README
%{_bindir}/*
%{_libdir}/*.a
%dir %{_datadir}/epsg_csv
%attr(0644,root,system) %{_datadir}/epsg_csv/*.csv
/usr/bin/*
/usr/lib/*.a


%files devel
%defattr(-,root,system,-)
%attr(0644,root,system) %{_includedir}/*
%{_libdir}/*.la
%{_libdir64}/*.la
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir64}/pkgconfig/%{name}.pc
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%changelog
* Tue Jul 16 2019 Michael Perzl <michael@perzl.org> - 1.4.3-1
- updated to version 1.4.3-1

* Tue Oct 30 2018 Michael Perzl <michael@perzl.org> - 1.4.2-1
- updated to version 1.4.2-1

* Tue Oct 30 2018 Michael Perzl <michael@perzl.org> - 1.4.1-1
- updated to version 1.4.1-1

* Wed May 02 2012 Michael Perzl <michael@perzl.org> - 1.4.0-1
- updated to version 1.4.0-1

* Mon May 10 2010 Michael Perzl <michael@perzl.org> - 1.3.0-1
- updated to version 1.3.0-1

* Mon May 10 2010 Michael Perzl <michael@perzl.org> - 1.2.5-1
- updated to version 1.2.5-1

* Thu May 15 2008 Michael Perzl <michael@perzl.org> - 1.2.4-1
- first version for AIX V5.1 and higher
